/*
 * MikroSDK - MikroE Software Development Kit
 * Copyright (c) 2019, MikroElektronika - www.mikroe.com
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

/*!
 * \file
 *
 */

#include "irdistance.h"


// ------------------------------------------------ PUBLIC FUNCTION DEFINITIONS

void irdistance_cfg_setup ( irdistance_cfg_t *cfg )
{
    // Additional gpio pins

    cfg->out = HAL_PIN_NC;
    cfg->en  = HAL_PIN_NC;

    cfg->channel      = ADC_CHANNEL_3;
    cfg->resolution   = ADC_RESOLUTION_DEFAULT;
    cfg->vref         = ADC_VREF_DEFAULT;
}

IRDISTANCE_RETVAL irdistance_init ( irdistance_t *ctx, irdistance_cfg_t *cfg )
{
    analog_in_config_t adc_cfg;

    analog_in_configure_default( &adc_cfg );
    adc_cfg.pin        = cfg->out;
    adc_cfg.channel    = cfg->channel;
    adc_cfg.resolution = cfg->resolution;
    adc_cfg.vref       = cfg->vref;
 
    if ( analog_in_open( &ctx->adc, &adc_cfg ) != ADC_SUCCESS )
    {
        return IRDISTANCE_INIT_ERROR;
    }

    // Output pins 

    digital_out_init( &ctx->en, cfg->en );

    return IRDISTANCE_OK;
}

void irdistance_default_cfg ( irdistance_t *ctx )
{
    irdistance_enable( ctx );
}

void irdistance_enable ( irdistance_t *ctx )
{
    digital_out_high( &ctx->en );
}

void irdistance_disable ( irdistance_t *ctx )
{
    digital_out_low( &ctx->en );
}

irdistance_data_t irdistance_read_adc ( irdistance_t *ctx )
{
    return analog_in_read( &ctx->adc );
}

float irdistance_get_voltage_out ( irdistance_data_t adc_value, uint16_t resolution_value, float vcc_value )
{
    float v_out;

    v_out = ( float ) adc_value;
    v_out *= vcc_value;
    v_out /= resolution_value;

    return v_out;
}

// ------------------------------------------------------------------------- END

