/*!
 * \file 
 * \brief IR distance Click example
 * 
 * # Description
 * The click board outputs an analog voltage corresponding to the distance of the object 
 * (through the mikroBUS AN pin). An Enable (EN) pin is also utilized.
 *
 * The demo application is composed of two sections :
 * 
 * ## Application Init 
 * Initialization driver enables GPIO, enable IR sensor, initialization ADC, also write log.
 * 
 * ## Application Task  
 * This is an example which demonstrates the use of IR Distance click board.
 * IR Distance click reads and displays ADC value.
 * Results are being sent to the Usart Terminal where you can track their changes.
 * All data logs on USB uart change for every 1 sec.
 * 
 * 
 * \author MikroE Team
 *
 */
// ------------------------------------------------------------------- INCLUDES

#include "board.h"
#include "log.h"
#include "irdistance.h"

// ------------------------------------------------------------------ VARIABLES

static irdistance_t irdistance;
static log_t logger;

static irdistance_data_t adc_val;

// ------------------------------------------------------ APPLICATION FUNCTIONS

void application_init ( void )
{
    log_cfg_t log_cfg;
    irdistance_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, "---- Application Init ----" );

    //  Click initialization.

    irdistance_cfg_setup( &cfg );
    IRDISTANCE_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    irdistance_init( &irdistance, &cfg );
    irdistance_default_cfg ( &irdistance );
}

void application_task ( void )
{
    adc_val = irdistance_read_adc( &irdistance );
    log_printf( &logger, " ADC value : %u\r\n", adc_val );
    log_printf( &logger, "---------------------\r\n" );
   
    Delay_ms( 1000 );
}

void main ( void )
{
    application_init( );

    for ( ; ; )
    {
        application_task( );
    }
}


// ------------------------------------------------------------------------ END
